import React, { useEffect, useState } from 'react'
import { Button } from '..';
import Slider from '../Slider';
import Utils from './Utils'
import { SlidingDateSelectorProps } from './SlidingDateSelector.types';

export enum Mode {
  DAY,
  MONTH,
  YEAR,
}

const SlidingDateSelector = (props: SlidingDateSelectorProps) => {
  const [numberOfDaysInMonth, setNumberOfDaysInMonth] = useState<number>(1);

  useEffect(() => {
    setToday();
  }, []);

  const changeMonth = (month: number) => {
    props.setMonth(month);
    updateNumberOfDaysInMonth(props.selectedYear, month)
  }

  const changeYear = (year: number) => {
    props.setYear(year);
    updateNumberOfDaysInMonth(year, props.selectedMonth)
  }

  const getMonthName = (monthIn: number) => {
    var objDate = new Date();
    objDate.setDate(1);
    objDate.setMonth(monthIn - 1);

    var locale = "da-dk",
      month = objDate.toLocaleString(locale, { month: "long" });
    return month;
  }

  const updateNumberOfDaysInMonth = (year: number, month: number) => {
    const newNumberOfDaysInMonth = Utils.calcNumberOfDaysInMonth(year, month);
    if (props.selectedDay > newNumberOfDaysInMonth) {
      props.setDay(newNumberOfDaysInMonth)
    }
    setNumberOfDaysInMonth(newNumberOfDaysInMonth)
  }

  const setToday = () => {
    const today = new Date();
    const year = today.getFullYear();
    const month = today.getMonth() + 1;
    props.setDay(today.getDate());
    props.setMonth(month);
    props.setYear(year);
    setNumberOfDaysInMonth(Utils.calcNumberOfDaysInMonth(year, month))
  }

  return (
    <>
      <>
        <Button
          color={''}
          onClick={() => {
            setToday();
            props.setMode(Mode.DAY)
          }}
          text="I dag"
        ></Button>

        <Button
          color={props.mode === Mode.DAY ? '#0092d6' : ''}
          onClick={() => { props.setMode(Mode.DAY) }}
          text="En dag"
        ></Button>

        <Button
          color={props.mode === Mode.MONTH ? '#0092d6' : ''}
          onClick={() => { props.setMode(Mode.MONTH) }}
          text="En måned"
        ></Button>

        <Button
          color={props.mode === Mode.YEAR ? '#0092d6' : ''}
          onClick={() => { props.setMode(Mode.YEAR) }}
          text="Et år"
        ></Button>
      </>
      <>
        {
          props.mode === Mode.DAY &&
          <Slider label="d. " valueAsString={ props.selectedDay ? props.selectedDay.toString() : '' } value={props.selectedDay} minValue={1} maxValue={numberOfDaysInMonth} changeValue={props.setDay}></Slider>
        }
        {
          (props.mode === Mode.MONTH || props.mode === Mode.DAY) &&
          <Slider label="" valueAsString={getMonthName(props.selectedMonth)} value={props.selectedMonth} minValue={1} maxValue={12} changeValue={changeMonth}></Slider>
        }
        <Slider label='' valueAsString={ props.selectedYear ? props.selectedYear.toString() : '' } value={props.selectedYear} minValue={props.minYear} maxValue={props.maxYear} changeValue={changeYear}></Slider>
      </>
    </>
  )
}

export default SlidingDateSelector